@@ -11,6 +11,9 @@ import os
 import sys
 sys.path.insert(0, os.path.abspath('..'))
 
+def foo():
+    print(os.getcwd())
+
 def generate_html(template_config):
     with open('static/templates_auto/0/index.html', 'r') as fp:
         template_str = Template(fp.read())
